from enum import IntEnum


class Alignment(IntEnum):
    """Enum for text alignment types within a table cell

    Example::

        from table2ascii import Alignment, table2ascii

        table2ascii(
            header=["Product", "Category", "Price", "In Stock"],
            body=[
                ["Milk", "Dairy", "$2.99", "Yes"],
                ["Cheese", "Dairy", "$10.99", "No"],
                ["Apples", "Produce", "$0.99", "Yes"],
            ],
            alignments=[Alignment.LEFT, Alignment.CENTER, Alignment.RIGHT, Alignment.LEFT],
        )

        \"\"\"
        ╔════════════════════════════════════════╗
        ║ Product   Category    Price   In Stock ║
        ╟────────────────────────────────────────╢
        ║ Milk       Dairy      $2.99   Yes      ║
        ║ Cheese     Dairy     $10.99   No       ║
        ║ Apples    Produce     $0.99   Yes      ║
        ╚════════════════════════════════════════╝
        \"\"\"
    """

    LEFT = 0
    CENTER = 1
    RIGHT = 2



import sys
from abc import abstractmethod
from typing import TYPE_CHECKING

if sys.version_info >= (3, 8):
    from typing import Protocol, runtime_checkable
else:
    from typing_extensions import Protocol, runtime_checkable

if TYPE_CHECKING:
    from typing import Protocol


@runtime_checkable
class SupportsStr(Protocol):
    """An ABC with one abstract method __str__."""

    @abstractmethod
    def __str__(self) -> str:
        pass
